package App::coldigits ;  
our $VERSION = '0.016' ; 
our $DATE = '2024-11-23T20:00+09:00' ; 

=encoding utf8

=head1 NAME

App::coldigits - TSVファイルの各列が何桁のものが何件あったかを、行列状に示す。

=head1 SYNOPSIS

This module provides a Unix-like command `F<coldigits>'. 

=head1 DESCRIPTION

=head1 SEE ALSO

coldigits --help
man coldigits
perldoc coldigits

=cut

1 ;
